From 15deaab0b364102bd33b6fe926959599dd07b12b Mon Sep 17 00:00:00 2001
From: Bharath Rupireddy <bharath.rupireddyforpostgres@gmail.com>
Date: Sat, 13 Nov 2021 13:58:53 +0000
Subject: [PATCH v1] add log messages that are equivalent of ps display
 activitymsgs

---
 src/backend/access/transam/xlog.c     |  6 ++++++
 src/backend/postmaster/pgarch.c       |  2 ++
 src/backend/replication/basebackup.c  | 12 ++++++------
 src/backend/replication/walreceiver.c | 26 ++++++++++++++------------
 src/backend/replication/walsender.c   | 12 ++++++------
 5 files changed, 34 insertions(+), 24 deletions(-)

diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
index e073121a7e..00eb71db79 100644
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -3791,6 +3791,8 @@ XLogFileRead(XLogSegNo segno, int emode, TimeLineID tli,
 					 xlogfname);
 			set_ps_display(activitymsg);
 
+			ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
+
 			if (!RestoreArchivedFile(path, xlogfname,
 									 "RECOVERYXLOG",
 									 wal_segment_size,
@@ -3833,6 +3835,8 @@ XLogFileRead(XLogSegNo segno, int emode, TimeLineID tli,
 				 xlogfname);
 		set_ps_display(activitymsg);
 
+		ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
+
 		/* Track source of data in assorted state variables */
 		readSource = source;
 		XLogReceiptSource = source;
@@ -9067,6 +9071,8 @@ update_checkpoint_display(int flags, bool restartpoint, bool reset)
 				 (flags & CHECKPOINT_IS_SHUTDOWN) ? "shutdown " : "",
 				 restartpoint ? "restartpoint" : "checkpoint");
 		set_ps_display(activitymsg);
+
+		ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
 	}
 }
 
diff --git a/src/backend/postmaster/pgarch.c b/src/backend/postmaster/pgarch.c
index 3b33e01d95..9020b786b1 100644
--- a/src/backend/postmaster/pgarch.c
+++ b/src/backend/postmaster/pgarch.c
@@ -555,6 +555,8 @@ pgarch_archiveXlog(char *xlog)
 	snprintf(activitymsg, sizeof(activitymsg), "archiving %s", xlog);
 	set_ps_display(activitymsg);
 
+	ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
+
 	rc = system(xlogarchcmd);
 	if (rc != 0)
 	{
diff --git a/src/backend/replication/basebackup.c b/src/backend/replication/basebackup.c
index ec0485705d..4a15ea33b3 100644
--- a/src/backend/replication/basebackup.c
+++ b/src/backend/replication/basebackup.c
@@ -867,19 +867,19 @@ SendBaseBackup(BaseBackupCmd *cmd)
 {
 	basebackup_options opt;
 	bbsink	   *sink;
+	char		activitymsg[50];
 
 	parse_basebackup_options(cmd->options, &opt);
 
 	WalSndSetState(WALSNDSTATE_BACKUP);
 
-	if (update_process_title)
-	{
-		char		activitymsg[50];
+	snprintf(activitymsg, sizeof(activitymsg), "sending backup \"%s\"",
+			 opt.label);
 
-		snprintf(activitymsg, sizeof(activitymsg), "sending backup \"%s\"",
-				 opt.label);
+	if (update_process_title)
 		set_ps_display(activitymsg);
-	}
+
+	ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
 
 	/* Create a basic basebackup sink. */
 	sink = bbsink_copytblspc_new();
diff --git a/src/backend/replication/walreceiver.c b/src/backend/replication/walreceiver.c
index 7a7eb3784e..aa995cda56 100644
--- a/src/backend/replication/walreceiver.c
+++ b/src/backend/replication/walreceiver.c
@@ -643,6 +643,7 @@ WalRcvWaitForStartPosition(XLogRecPtr *startpoint, TimeLineID *startpointTLI)
 {
 	WalRcvData *walrcv = WalRcv;
 	int			state;
+	char		activitymsg[50];
 
 	SpinLockAcquire(&walrcv->mutex);
 	state = walrcv->walRcvState;
@@ -704,14 +705,13 @@ WalRcvWaitForStartPosition(XLogRecPtr *startpoint, TimeLineID *startpointTLI)
 						 WAIT_EVENT_WAL_RECEIVER_WAIT_START);
 	}
 
-	if (update_process_title)
-	{
-		char		activitymsg[50];
+	snprintf(activitymsg, sizeof(activitymsg), "restarting at %X/%X",
+			 LSN_FORMAT_ARGS(*startpoint));
 
-		snprintf(activitymsg, sizeof(activitymsg), "restarting at %X/%X",
-				 LSN_FORMAT_ARGS(*startpoint));
+	if (update_process_title)
 		set_ps_display(activitymsg);
-	}
+
+	ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
 }
 
 /*
@@ -965,6 +965,8 @@ XLogWalRcvWrite(char *buf, Size nbytes, XLogRecPtr recptr, TimeLineID tli)
 static void
 XLogWalRcvFlush(bool dying, TimeLineID tli)
 {
+	char		activitymsg[50];
+
 	Assert(tli != 0);
 
 	if (LogstreamResult.Flush < LogstreamResult.Write)
@@ -990,15 +992,15 @@ XLogWalRcvFlush(bool dying, TimeLineID tli)
 		if (AllowCascadeReplication())
 			WalSndWakeup();
 
+
+		snprintf(activitymsg, sizeof(activitymsg), "streaming %X/%X",
+				 LSN_FORMAT_ARGS(LogstreamResult.Write));
+
 		/* Report XLOG streaming progress in PS display */
 		if (update_process_title)
-		{
-			char		activitymsg[50];
-
-			snprintf(activitymsg, sizeof(activitymsg), "streaming %X/%X",
-					 LSN_FORMAT_ARGS(LogstreamResult.Write));
 			set_ps_display(activitymsg);
-		}
+
+		ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
 
 		/* Also let the primary know that we made some progress */
 		if (!dying)
diff --git a/src/backend/replication/walsender.c b/src/backend/replication/walsender.c
index 7950afb173..273ce0cc8a 100644
--- a/src/backend/replication/walsender.c
+++ b/src/backend/replication/walsender.c
@@ -2662,6 +2662,7 @@ XLogSendPhysical(void)
 	Size		nbytes;
 	XLogSegNo	segno;
 	WALReadError errinfo;
+	char		activitymsg[50];
 
 	/* If requested switch the WAL sender to the stopping state. */
 	if (got_STOPPING)
@@ -2939,15 +2940,14 @@ retry:
 		SpinLockRelease(&walsnd->mutex);
 	}
 
+	snprintf(activitymsg, sizeof(activitymsg), "streaming %X/%X",
+			 LSN_FORMAT_ARGS(sentPtr));
+
 	/* Report progress of XLOG streaming in PS display */
 	if (update_process_title)
-	{
-		char		activitymsg[50];
-
-		snprintf(activitymsg, sizeof(activitymsg), "streaming %X/%X",
-				 LSN_FORMAT_ARGS(sentPtr));
 		set_ps_display(activitymsg);
-	}
+
+	ereport(DEBUG1, (errmsg_internal("%s", activitymsg)));
 }
 
 /*
-- 
2.25.1

